@@ -238,6 +238,8 @@ class AccountFiles:
             assert isinstance(self.name_index, dict)
         except OSErrors as e:
             comment(os_error(e))
+        except Exception as e:
+            comment(e)
 
     def write_manifests(self):  # {{{2
         # do not modify existing name_index if no account files were loaded
@@ -256,12 +258,12 @@ class AccountFiles:
 
         # build name manifests
         for name, account in Account._accounts.items():
-            filename = account._file_info.path.name
+            filename = account._file_info_.path.name
             name_manifests[filename].append(name)
 
         # build url and title manifests
         for account in Account.all_loaded_accounts():
-            filename = account._file_info.path.name
+            filename = account._file_info_.path.name
             if filename not in self.loaded:
                 # This should not occur, but if PasswordGenerator is
                 # instantiated more than once, which should only occur in the
@@ -302,6 +304,8 @@ class AccountFiles:
         contents = pickle.dumps(cache)
 
         user_key = get_setting('user_key')
+        if not user_key:
+            return
         key = base64.urlsafe_b64encode(sha256(user_key.encode('ascii')).digest())
         fernet = Fernet(key)
         encrypted = fernet.encrypt(contents)
