@@ -1216,6 +1216,8 @@ class Secrets(HelpMessage):
             secure (bool):
                 Indicates that this secret should only be contained in an
                 encrypted accounts file. Default is True.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
@@ -1238,6 +1240,8 @@ class Secrets(HelpMessage):
                 encrypted accounts file. Default is True.
             encoding (str):
                 The encoding to use for the deciphered text.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
@@ -1383,6 +1387,8 @@ class Secrets(HelpMessage):
                 A string added to the front of the generated password.
             suffix (str):
                 A string added to the end of the generated password.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
@@ -1405,9 +1411,16 @@ class Secrets(HelpMessage):
                 The number of items to draw from the alphabet when creating the
                 password.  When using the default alphabet, this will be the
                 number of words in the passphrase.
-            alphabet (str):
+            dictionary (str, [str], or callable):
                 The reservoir of legal symbols to use when creating the
-                password. By default, this is a predefined list of 10,000 words.
+                password. If not given, or if 'default' is given, this is a
+                predefined list of 10,000 words. If given as 'bip39' or
+                'mnemonic', this is a predefined list of the 2048 bitcoin BIP-39
+                seed words.  Any other string is treated as a path to a file
+                that would contain the words. A list is taken as is. Finally,
+                you can pass a function that returns the list of words, in which
+                case the calling of the function is deferred until the words are
+                needed, which is helpful if creating the list is slow.
             master (str):
                 Overrides the master seed that is used when generating the
                 password.  Generally, there is one master seed shared by all
@@ -1424,6 +1437,8 @@ class Secrets(HelpMessage):
                 A string added to the front of the generated password.
             suffix (str):
                 A string added to the end of the generated password.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
@@ -1455,6 +1470,8 @@ class Secrets(HelpMessage):
             version (str):
                 An optional seed. Changing this value will change the generated
                 PIN.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
@@ -1485,9 +1502,19 @@ class Secrets(HelpMessage):
                 The number of items to draw from the alphabet when creating the
                 password. When using the default alphabet, this will be the
                 number of words in the answer.
-            alphabet (list of strs):
+            answer:
+                The answer. If provided, this would override the generated
+                answer.  May be a string, or it may be an Obscured object.
+            dictionary (str, [str], or callable):
                 The reservoir of legal symbols to use when creating the
-                password. By default, this is a predefined list of 10,000 words.
+                password. If not given, or if 'default' is given, this is a
+                predefined list of 10,000 words. If given as 'bip39' or
+                'mnemonic', this is a predefined list of the 2048 bitcoin BIP-39
+                seed words.  Any other string is treated as a path to a file
+                that would contain the words. A list is taken as is. Finally,
+                you can pass a function that returns the list of words, in which
+                case the calling of the function is deferred until the words are
+                needed, which is helpful if creating the list is slow.
             master (str):
                 Overrides the master seed that is used when generating the
                 password.  Generally, there is one master seed shared by all
@@ -1504,9 +1531,8 @@ class Secrets(HelpMessage):
                 A string added to the front of the generated password.
             suffix (str):
                 A string added to the end of the generated password.
-            answer:
-                The answer. If provided, this would override the generated
-                answer.  May be a string, or it may be an Obscured object.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
@@ -1566,6 +1592,8 @@ class Secrets(HelpMessage):
                 the characters that require the shift key when typing are placed
                 last, making it easier to type. Use this option if you expect to
                 be typing the password by hand.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
@@ -1603,6 +1631,8 @@ class Secrets(HelpMessage):
             version (str):
                 An optional seed. Changing this value will change the generated
                 answer.
+            is_secret (bool):
+                Should value be hidden from user unless explicitly requested.
 
         Example:
 
